==> WPyrogram-2.0.136-py3-none-any.whl: pyrogram/raw/base/messages/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .dialogs import Dialogs
from .messages import Messages
from .chats import Chats
from .chat_full import ChatFull
from .affected_history import AffectedHistory
from .dh_config import DhConfig
from .sent_encrypted_message import SentEncryptedMessage
from .stickers import Stickers
from .all_stickers import AllStickers
from .affected_messages import AffectedMessages
from .sticker_set import StickerSet
from .saved_gifs import SavedGifs
from .bot_results import BotResults
from .bot_callback_answer import BotCallbackAnswer
from .message_edit_data import MessageEditData
from .peer_dialogs import PeerDialogs
from .featured_stickers import FeaturedStickers
from .recent_stickers import RecentStickers
from .archived_stickers import ArchivedStickers
from .sticker_set_install_result import StickerSetInstallResult
from .high_scores import HighScores
from .faved_stickers import FavedStickers
from .found_sticker_sets import FoundStickerSets
from .search_counter import SearchCounter
from .inactive_chats import InactiveChats
from .votes_list import VotesList
from .message_views import MessageViews
from .discussion_message import DiscussionMessage
from .history_import import HistoryImport
from .history_import_parsed import HistoryImportParsed
from .affected_found_messages import AffectedFoundMessages
from .exported_chat_invites import ExportedChatInvites
from .exported_chat_invite import ExportedChatInvite
from .chat_invite_importers import ChatInviteImporters
from .chat_admins_with_invites import ChatAdminsWithInvites
from .checked_history_import_peer import CheckedHistoryImportPeer
from .sponsored_messages import SponsoredMessages
from .search_results_calendar import SearchResultsCalendar
from .search_results_positions import SearchResultsPositions
from .peer_settings import PeerSettings
from .message_reactions_list import MessageReactionsList
from .available_reactions import AvailableReactions
from .transcribed_audio import TranscribedAudio
from .reactions import Reactions
from .forum_topics import ForumTopics
from .emoji_groups import EmojiGroups
from .translated_text import TranslatedText
from .bot_app import BotApp
from .web_page import WebPage
from .saved_dialogs import SavedDialogs

==> WPyrogram-2.0.142-py3-none-any.whl: pyrogram/raw/base/messages/__init__.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-present Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .dialogs import Dialogs
from .messages import Messages
from .chats import Chats
from .chat_full import ChatFull
from .affected_history import AffectedHistory
from .dh_config import DhConfig
from .sent_encrypted_message import SentEncryptedMessage
from .stickers import Stickers
from .all_stickers import AllStickers
from .affected_messages import AffectedMessages
from .sticker_set import StickerSet
from .saved_gifs import SavedGifs
from .bot_results import BotResults
from .bot_callback_answer import BotCallbackAnswer
from .message_edit_data import MessageEditData
from .peer_dialogs import PeerDialogs
from .featured_stickers import FeaturedStickers
from .recent_stickers import RecentStickers
from .archived_stickers import ArchivedStickers
from .sticker_set_install_result import StickerSetInstallResult
from .high_scores import HighScores
from .faved_stickers import FavedStickers
from .found_sticker_sets import FoundStickerSets
from .search_counter import SearchCounter
from .inactive_chats import InactiveChats
from .votes_list import VotesList
from .message_views import MessageViews
from .discussion_message import DiscussionMessage
from .history_import import HistoryImport
from .history_import_parsed import HistoryImportParsed
from .affected_found_messages import AffectedFoundMessages
from .exported_chat_invites import ExportedChatInvites
from .exported_chat_invite import ExportedChatInvite
from .chat_invite_importers import ChatInviteImporters
from .chat_admins_with_invites import ChatAdminsWithInvites
from .checked_history_import_peer import CheckedHistoryImportPeer
from .sponsored_messages import SponsoredMessages
from .search_results_calendar import SearchResultsCalendar
from .search_results_positions import SearchResultsPositions
from .peer_settings import PeerSettings
from .message_reactions_list import MessageReactionsList
from .available_reactions import AvailableReactions
from .transcribed_audio import TranscribedAudio
from .reactions import Reactions
from .forum_topics import ForumTopics
from .emoji_groups import EmojiGroups
from .translated_text import TranslatedText
from .bot_app import BotApp
from .web_page import WebPage
from .saved_dialogs import SavedDialogs
from .saved_reaction_tags import SavedReactionTags
from .quick_replies import QuickReplies
from .dialog_filters import DialogFilters
